@@ -27,14 +27,12 @@ pip install cloudcomponents.cdk-pull-request-approval-rule
 ## How to use
 
 ```python
-import { Construct, Stack, StackProps } from '@aws-cdk/core';
-import { Repository } from '@aws-cdk/aws-codecommit';
-import { BuildSpec } from '@aws-cdk/aws-codebuild';
+import { ApprovalRuleTemplate, ApprovalRuleTemplateRepositoryAssociation } from '@cloudcomponents/cdk-pull-request-approval-rule';
 import { PullRequestCheck } from '@cloudcomponents/cdk-pull-request-check';
-import {
-  ApprovalRuleTemplate,
-  ApprovalRuleTemplateRepositoryAssociation,
-} from '@cloudcomponents/cdk-pull-request-approval-rule';
+import { Stack, StackProps } from 'aws-cdk-lib';
+import { BuildSpec } from 'aws-cdk-lib/aws-codebuild';
+import { Repository } from 'aws-cdk-lib/aws-codecommit';
+import { Construct } from 'constructs';
 
 export class PullRequestStack extends Stack {
   constructor(scope: Construct, id: string, props?: StackProps) {
@@ -44,27 +42,19 @@ export class PullRequestStack extends Stack {
       repositoryName: 'pr-check-repository',
     });
 
-    const { approvalRuleTemplateName } = new ApprovalRuleTemplate(
-      this,
-      'ApprovalRuleTemplate',
-      {
-        approvalRuleTemplateName: 'template-name',
-        template: {
-          approvers: {
-            numberOfApprovalsNeeded: 1,
-          },
+    const { approvalRuleTemplateName } = new ApprovalRuleTemplate(this, 'ApprovalRuleTemplate', {
+      approvalRuleTemplateName: 'template-name',
+      template: {
+        approvers: {
+          numberOfApprovalsNeeded: 1,
         },
       },
-    );
+    });
 
-    new ApprovalRuleTemplateRepositoryAssociation(
-      this,
-      'ApprovalRuleTemplateRepositoryAssociation',
-      {
-        approvalRuleTemplateName,
-        repository,
-      },
-    );
+    new ApprovalRuleTemplateRepositoryAssociation(this, 'ApprovalRuleTemplateRepositoryAssociation', {
+      approvalRuleTemplateName,
+      repository,
+    });
 
     new PullRequestCheck(this, 'PullRequestCheck', {
       repository,
@@ -77,14 +67,14 @@ export class PullRequestStack extends Stack {
 ## ApprovalRuleOverridden notification
 
 ```python
-import { Construct, Stack, StackProps } from '@aws-cdk/core';
-import { Repository } from '@aws-cdk/aws-codecommit';
-import { BuildSpec } from '@aws-cdk/aws-codebuild';
+import { ApprovalRuleTemplate, ApprovalRuleTemplateRepositoryAssociation } from '@cloudcomponents/cdk-pull-request-approval-rule';
 import { PullRequestCheck } from '@cloudcomponents/cdk-pull-request-check';
-import {
-  ApprovalRuleTemplate,
-  ApprovalRuleTemplateRepositoryAssociation,
-} from '@cloudcomponents/cdk-pull-request-approval-rule';
+import { Stack, StackProps } from 'aws-cdk-lib';
+import { BuildSpec } from 'aws-cdk-lib/aws-codebuild';
+import { Repository } from 'aws-cdk-lib/aws-codecommit';
+import { SnsTopic } from 'aws-cdk-lib/aws-events-targets';
+import { Topic } from 'aws-cdk-lib/aws-sns';
+import { Construct } from 'constructs';
 
 export class PullRequestStack extends Stack {
   constructor(scope: Construct, id: string, props?: StackProps) {
@@ -157,17 +147,17 @@ from ._jsii import *
 
 import aws_cdk.aws_codecommit
 import aws_cdk.aws_events
-import aws_cdk.core
+import constructs
 
 
 class ApprovalRuleTemplate(
-    aws_cdk.core.Construct,
+    constructs.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cloudcomponents/cdk-pull-request-approval-rule.ApprovalRuleTemplate",
 ):
     def __init__(
         self,
-        scope: aws_cdk.core.Construct,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
         approval_rule_template_name: builtins.str,
@@ -259,13 +249,13 @@ class ApprovalRuleTemplateProps:
 
 
 class ApprovalRuleTemplateRepositoryAssociation(
-    aws_cdk.core.Construct,
+    constructs.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cloudcomponents/cdk-pull-request-approval-rule.ApprovalRuleTemplateRepositoryAssociation",
 ):
     def __init__(
         self,
-        scope: aws_cdk.core.Construct,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
         approval_rule_template_name: builtins.str,
