@@ -8,16 +8,14 @@ import jsii
 import publication
 import typing_extensions
 
-import aws_cdk.aws_codecommit._jsii
-import aws_cdk.aws_events._jsii
-import aws_cdk.core._jsii
+import aws_cdk._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@cloudcomponents/cdk-pull-request-approval-rule",
-    "1.49.0",
+    "2.0.0",
     __name__[0:-6],
-    "cdk-pull-request-approval-rule@1.49.0.jsii.tgz",
+    "cdk-pull-request-approval-rule@2.0.0.jsii.tgz",
 )
 
 __all__ = [
